@@ -13,7 +13,12 @@ from .config import (
 from .errors import K4AException, K4ATimeoutException
 from .playback import PyK4APlayback, SeekOrigin
 from .pyk4a import ColorControlCapabilities, PyK4A
-from .transformation import color_image_to_depth_camera, depth_image_to_color_camera, depth_image_to_point_cloud
+from .transformation import (
+    color_image_to_depth_camera,
+    depth_image_to_color_camera,
+    depth_image_to_color_camera_custom,
+    depth_image_to_point_cloud,
+)
 
 
 __all__ = (
@@ -37,4 +42,5 @@ __all__ = (
     "color_image_to_depth_camera",
     "depth_image_to_point_cloud",
     "depth_image_to_color_camera",
+    "depth_image_to_color_camera_custom",
 )
